"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const service_1 = require("../service");
const BootstrapService_1 = require("../service/BootstrapService");
class Config extends command_1.Command {
    async run() {
        const { flags } = this.parse(Config);
        service_1.BootstrapUtils.showBanner();
        await new BootstrapService_1.BootstrapService(this.config.root).config(flags);
    }
}
exports.default = Config;
Config.description = 'Command used to set up the configuration files and the nemesis block for the current network';
Config.examples = [`$ symbol-bootstrap config -p bootstrap`];
Config.flags = {
    help: command_1.flags.help({ char: 'h', description: 'It shows the help of this command.' }),
    preset: command_1.flags.enum({
        char: 'p',
        description: 'the network preset',
        options: Object.keys(service_1.Preset).map((v) => v),
        default: service_1.ConfigService.defaultParams.preset,
    }),
    assembly: command_1.flags.string({
        char: 'a',
        description: 'An optional assembly type, example "dual" for testnet',
    }),
    target: command_1.flags.string({
        char: 't',
        description: 'the target folder',
        default: service_1.ConfigService.defaultParams.target,
    }),
    customPreset: command_1.flags.string({
        char: 'c',
        description: 'External preset file. Values in this file will override the provided presets (optional)',
        required: false,
    }),
    reset: command_1.flags.boolean({
        char: 'r',
        description: 'It resets the configuration generating a new one',
        default: service_1.ConfigService.defaultParams.reset,
    }),
};
